@@ -1,10 +1,10 @@
-#include <Wt/WText>
+#include <Wt/WText.h>
 
 SAMPLE_BEGIN(TextXHTML)
-Wt::WText *text
-    = new Wt::WText("This is <b>XHTML</b> markup text. "
+auto text
+    = Wt::cpp14::make_unique<Wt::WText>("This is <b>XHTML</b> markup text. "
 		    "It supports a safe subset of XHTML tags and "
 		    "attributes, which have only decorative "
 		    "functions.");
 
-SAMPLE_END(return text)
+SAMPLE_END(return std::move(text))
